@@ -2,7 +2,7 @@ from django import template
 from django.contrib import admin
 from django.core.handlers.wsgi import WSGIRequest
 from django.core.urlresolvers import reverse
-from suit import get_config
+from suit.config import get_config
 
 register = template.Library()
 
